@@ -142,9 +142,9 @@ interpret.numeric <- function(x, rules, name = attr(rules, "rule_name"), ...) {
   attr(rules, "rule_name") <- name
 
   if (length(x) > 1) {
-    out <- sapply(x, .interpret, rules)
+    out <- vapply(x, .interpret, rules = rules, FUN.VALUE = character(1L))
   } else {
-    out <- .interpret(x, rules)
+    out <- .interpret(x, rules = rules)
   }
 
   names(out) <- names(x)
@@ -176,6 +176,7 @@ interpret.effectsize_table <- function(x, rules, ...) {
     phi_adjusted = ,
     Pearsons_c = ,
     Cohens_w = ,
+    Tschuprows_t = ,
     fei = interpret_cramers_v(value, rules = rules),
 
     ## xtab 2x2
@@ -193,6 +194,7 @@ interpret.effectsize_table <- function(x, rules, ...) {
     Eta2 = ,
     Eta2_partial = ,
     Eta2_generalized = ,
+    r2_semipartial = ,
     Epsilon2 = ,
     Epsilon2_partial = ,
     Omega2 = ,
@@ -223,7 +225,7 @@ interpret.effectsize_table <- function(x, rules, ...) {
 #' @keywords internal
 .interpret <- function(x, rules) {
   if (is.na(x)) {
-    return(NA)
+    return(NA_character_)
   }
 
   if (length(rules$values) == length(rules$labels)) {
