@@ -1,4 +1,10 @@
-# library(testthat)
+test_that("alternative = NULL", {
+  m <- aov(mpg ~ factor(cyl) + hp, mtcars)
+  expect_equal(
+    eta_squared(m),
+    eta_squared(m, alternative = NULL)
+  )
+})
 
 # anova() -----------------------------------------------------------------
 test_that("anova()", {
@@ -142,10 +148,12 @@ test_that("aovlist", {
   skip_if_not_installed("afex")
   # non-partial Eta2 should be the same for aov and aovlist
   data(obk.long, package = "afex")
-  model <- afex::aov_car(value ~ treatment * gender + Error(id / (phase * hour)),
-    data = obk.long, observed = "gender",
-    include_aov = TRUE
-  )
+  suppressMessages({
+    model <- afex::aov_car(value ~ treatment * gender + Error(id / (phase * hour)),
+      data = obk.long, observed = "gender",
+      include_aov = TRUE
+    )
+  })
 
   model2 <- aov(value ~ treatment * gender * phase * hour,
     data = model$data$long,
@@ -201,7 +209,7 @@ test_that("mlm / anova table", {
 
   # MANOVA table
   mod <- manova(cbind(mpg, qsec) ~ am_f * cyl_f, data = mtcars)
-  expect_equal(nrow(eta_squared(mod)), 3L)
+  expect_identical(nrow(eta_squared(mod)), 3L)
 
   # Row order
   fit <- lm(cbind(mpg, disp, hp) ~ factor(cyl), data = mtcars)
@@ -236,12 +244,12 @@ test_that("generalized | between", {
   skip_if_not_installed("car")
 
   data(obk.long, package = "afex")
-  m <- suppressWarnings(
-    afex::aov_car(value ~ treatment * gender + Error(id),
+  suppressMessages(suppressWarnings(
+    m <- afex::aov_car(value ~ treatment * gender + Error(id),
       data = obk.long, observed = "gender",
       include_aov = TRUE
     )
-  )
+  ))
 
   Aov <- car::Anova(m$aov, type = 3)
 
@@ -270,9 +278,11 @@ test_that("generalized | within-mixed", {
   data(obk.long, package = "afex")
 
   # estimate mixed ANOVA on the full design:
-  m <- afex::aov_car(value ~ treatment * gender + Error(id / (phase * hour)),
-    data = obk.long, observed = "gender",
-    include_aov = TRUE
+  suppressMessages(
+    m <- afex::aov_car(value ~ treatment * gender + Error(id / (phase * hour)),
+      data = obk.long, observed = "gender",
+      include_aov = TRUE
+    )
   )
 
 
@@ -316,12 +326,12 @@ test_that("omega", {
   # cross validated with MOTE
   data(obk.long, package = "afex")
 
-  m <- suppressWarnings(
-    afex::aov_car(value ~ treatment * gender + Error(id / (phase)),
+  suppressMessages(suppressWarnings(
+    m <- afex::aov_car(value ~ treatment * gender + Error(id / (phase)),
       data = obk.long, observed = "gender",
       include_aov = TRUE
     )
-  )
+  ))
 
 
   ef <- omega_squared(m, partial = TRUE, alternative = "two")
@@ -348,12 +358,12 @@ test_that("failed CIs", {
 
   expect_warning(eta_squared(model), regexp = "CIs")
   expect_warning(eta <- eta_squared(model, verbose = FALSE), regexp = NA)
-  expect_equal(nrow(eta), 2L)
+  expect_identical(nrow(eta), 2L)
   expect_equal(eta[1, "Eta2_partial"], 1)
 
   expect_warning(eta_squared(model, partial = FALSE), regexp = "CIs")
   expect_warning(eta <- eta_squared(model, partial = FALSE, verbose = FALSE), regexp = NA)
-  expect_equal(nrow(eta), 2L)
+  expect_identical(nrow(eta), 2L)
   expect_equal(eta[1, "Eta2"], 0.34, tolerance = 0.01)
 })
 
@@ -368,23 +378,23 @@ test_that("include_intercept | car", {
 
   res0 <- eta_squared(AOV, verbose = FALSE)
   res1 <- eta_squared(AOV, include_intercept = TRUE, verbose = FALSE)
-  expect_equal(nrow(res0), 3)
-  expect_equal(nrow(res1), nrow(res0) + 1)
-  expect_equal(res1[[1]][1], "(Intercept)")
+  expect_identical(nrow(res0), 3L)
+  expect_identical(nrow(res1), nrow(res0) + 1L)
+  expect_identical(res1[[1]][1], "(Intercept)")
   expect_equal(res1[[2]][1], 0.8680899, tolerance = 0.01)
 
   res0 <- epsilon_squared(AOV, verbose = FALSE)
   res1 <- epsilon_squared(AOV, include_intercept = TRUE, verbose = FALSE)
-  expect_equal(nrow(res0), 3)
-  expect_equal(nrow(res1), nrow(res0) + 1)
+  expect_identical(nrow(res0), 3L)
+  expect_identical(nrow(res1), nrow(res0) + 1L)
   expect_equal(res1[[1]][1], "(Intercept)")
 
 
   res0 <- omega_squared(AOV, verbose = FALSE)
   res1 <- omega_squared(AOV, include_intercept = TRUE, verbose = FALSE)
-  expect_equal(nrow(res0), 3)
-  expect_equal(nrow(res1), nrow(res0) + 1)
-  expect_equal(res1[[1]][1], "(Intercept)")
+  expect_identical(nrow(res0), 3L)
+  expect_identical(nrow(res1), nrow(res0) + 1L)
+  expect_identical(res1[[1]][1], "(Intercept)")
 
   # generalized
   res1 <- eta_squared(AOV, generalized = "cyl", include_intercept = TRUE, verbose = FALSE)
@@ -406,14 +416,14 @@ test_that("include_intercept | afex", {
 
   resE0 <- eta_squared(a, verbose = FALSE)
   resA0 <- anova(a, es = "pes")
-  expect_equal(nrow(resE0), 3)
-  expect_equal(nrow(resE0), nrow(resA0))
+  expect_identical(nrow(resE0), 3L)
+  expect_identical(nrow(resE0), nrow(resA0))
 
 
   resE1 <- eta_squared(a, include_intercept = TRUE, verbose = FALSE)
   resA1 <- anova(a, es = "pes", intercept = TRUE)
-  expect_equal(nrow(resE1), nrow(resE0) + 1)
-  expect_equal(nrow(resE1), nrow(resA1))
+  expect_identical(nrow(resE1), nrow(resE0) + 1L)
+  expect_identical(nrow(resE1), nrow(resA1))
 
   skip_if_not_installed("car")
   resE1 <- eta_squared(car::Anova(a$aov, type = 3), include_intercept = TRUE, generalized = "gender", verbose = FALSE)
@@ -430,11 +440,11 @@ test_that("afex | within-mixed", {
 
   data(obk.long, package = "afex")
 
-  mod <- afex::aov_ez("id", "value", obk.long,
+  suppressMessages(mod <- afex::aov_ez("id", "value", obk.long,
     between = c("treatment", "gender"),
     within = c("phase", "hour"),
     observed = "gender"
-  )
+  ))
 
   x <- eta_squared(mod, generalized = TRUE)
   a <- anova(mod, observed = "gender")
@@ -476,7 +486,7 @@ test_that("afex | within-mixed", {
       "C1", "C2", "C2", "C1", "C1", "C2", "C2"
     )
   )
-  mod <- afex::aov_ez("subject", "y", data, within = c("A", "B", "C"))
+  suppressMessages(mod <- afex::aov_ez("subject", "y", data, within = c("A", "B", "C")))
   tab <- as.data.frame(anova(mod, es = "pes"))
   res <- eta_squared(mod)
 
@@ -494,14 +504,31 @@ test_that("afex | mixed()", {
 
   data(md_15.1, package = "afex")
   # random intercept plus random slope
-  t15.4a <- afex::mixed(iq ~ timecat + (1 + time | id),
+  suppressMessages(t15.4a <- afex::mixed(iq ~ timecat + (1 + time | id),
     data = md_15.1,
     method = "S"
-  )
+  ))
   expect_equal(
     eta_squared(t15.4a),
     eta_squared(t15.4a$full_model)
   )
+
+  # Intercept
+  data("stroop", package = "afex")
+  stroop <- subset(stroop, study == 1 & acc == 1 & trialnum < 20)
+  suppressMessages(m1 <- afex::mixed(rt ~ condition + (condition | pno), data = stroop, method = "KR"))
+  suppressMessages(m2 <- afex::mixed(rt ~ condition + (condition | pno), data = stroop, test_intercept = TRUE, method = "KR"))
+
+  expect_warning(a1a <- eta_squared(m1, include_intercept = TRUE), regexp = "Intercept")
+  expect_warning(a1b <- eta_squared(m1, include_intercept = FALSE), regexp = NA)
+  expect_equal(a1a, a1b)
+  expect_equal(nrow(a1a), 1L)
+
+  expect_warning(a2a <- eta_squared(m2, include_intercept = TRUE), regexp = NA)
+  expect_warning(a2b <- eta_squared(m2, include_intercept = FALSE), regexp = NA)
+  expect_equal(nrow(a2a), 2L)
+  expect_equal(nrow(a2b), 1L)
+  expect_equal(a1a, a2a[2, ], ignore_attr = TRUE)
 })
 
 
@@ -519,32 +546,17 @@ test_that("car MVM", {
     id = 1:8
   )
 
-  ds_long <- data.frame(
-    id = c(
-      1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L,
-      1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L,
-      1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L,
-      1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L
-    ),
-    ind_var = c(
-      "I", "I", "I", "I", "I", "I", "I", "I",
-      "II", "II", "II", "II", "II", "II", "II", "II",
-      "III", "III", "III", "III", "III", "III", "III", "III",
-      "IV", "IV", "IV", "IV", "IV", "IV", "IV", "IV"
-    ),
-    score = c(
-      116, 96, 120, 110, 116, 126, 86, 80,
-      76, 93, 112, 113, 75, 120, 90, 105,
-      85, 63, 89, 60, 115, 101, 129, 67,
-      50, 87, 100, 60, 79, 70, 65, 65
+  ds_long <-
+    datawizard::reshape_longer(ds,
+      select = 1:4,
+      names_to = "ind_var",
+      values_to = "score"
     )
-  )
-
 
 
   fit <- lm(cbind(I, II, III, IV) ~ 1, data = ds)
   in_rep <- data.frame(ind_var = gl(4, 1))
-  A_car <- car::Anova(fit, idata = in_rep, idesign = ~ind_var)
+  suppressMessages(A_car <- car::Anova(fit, idata = in_rep, idesign = ~ind_var))
 
   eta_car <- effectsize::eta_squared(A_car, ci = NULL)[[2]]
 
@@ -558,11 +570,11 @@ test_that("car MVM", {
   # Complex ---
   data(obk.long, package = "afex")
 
-  mod <- afex::aov_ez("id", "value", obk.long,
+  suppressMessages(mod <- afex::aov_ez("id", "value", obk.long,
     between = c("treatment", "gender"),
     within = c("phase", "hour"),
     observed = "gender"
-  )
+  ))
   expect_equal(
     sort(eta_squared(mod$Anova, generalized = "gender")[[2]]),
     sort(mod$anova_table$ges)
@@ -574,12 +586,13 @@ test_that("Anova.mlm Manova", {
   skip_if_not_installed("car")
 
   data("mtcars")
+  mtcars <- mtcars[c(1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 18L, 29L, 31L), ]
   mtcars$am_f <- factor(mtcars$am)
   mtcars$cyl_f <- factor(mtcars$cyl)
 
-  mod <- lm(cbind(mpg, qsec) ~ am_f * cyl_f, data = mtcars)
+  mod <- lm(cbind(mpg, qsec, disp) ~ am_f * cyl_f, data = mtcars)
 
-  Manova <- car::Manova(mod)
+  Manova <- car::Manova(mod, type = 2)
 
   expect_true(is.null(summary(Manova, univariate = TRUE)[["univariate.tests"]]))
   expect_error(eta_squared(Manova), regexp = NA)
@@ -587,6 +600,18 @@ test_that("Anova.mlm Manova", {
     eta_squared(manova(mod))[[2]][2:3],
     eta_squared(Manova)[[2]][2:3]
   )
+
+  Anova <- car::Anova(mod, idesign = ~g, idata = data.frame(g = factor(1:3)))
+  mtcars$id <- factor(seq(nrow(mtcars)))
+  mtcars_long <- datawizard::reshape_longer(mtcars,
+    select = c("mpg", "qsec", "disp"), names_to = "g"
+  )
+  a1 <- aov(value ~ am_f * cyl_f * g + Error(id / g), data = mtcars_long)
+
+  A1 <- eta_squared(Anova)
+  A2 <- eta_squared(a1)
+  expect_equal(A1$Parameter, A2$Parameter)
+  expect_equal(A1[c(2:4, 6:7), ], A2[c(2:4, 6:7), -1], ignore_attr = TRUE)
 })
 
 ## merMod --------------------
@@ -631,7 +656,7 @@ test_that("ets_squared | gam", {
   skip_if_not_installed("mgcv")
 
   set.seed(2) ## simulate some data...
-  dat <- mgcv::gamSim(1, n = 400, dist = "normal", scale = 2)
+  dat <- mgcv::gamSim(1, n = 400, dist = "normal", scale = 2, verbose = FALSE)
   b <- mgcv::gam(y ~ x0 + s(x1) + s(x2) + t2(x1, x2) + s(x3), data = dat)
 
   expect_error(out <- eta_squared(b), regexp = NA)
